/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * Copyright (c) 2004 Nokia. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Nokia nor the names of its contributors may be
 * used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef PageLoadListener_h
#define PageLoadListener_h

#include <assert.h>

#include "osb.h"
#include "loader/HTTP.h"
#include "ref_gobjectptr.h"
#include "webi-external-content-delegate.h"


class BridgeImpl;
class DataAdder;

class PageLoadStatus : public OSB::ResourceStatus
{
    friend class PageLoadListener;
public:
    PageLoadStatus(const gchar * name = 0) : ResourceStatus(name) {}
};

class PageLoadListener : public Loader::RequestListener, public Loader::HTTPHeaderListener
{
public:
    PageLoadListener(BridgeImpl* b, const gchar* URL);
    ~PageLoadListener();

    void externalLoadCancelled();
    
    void setRequest(Loader::Request* r) { assert(!m_request); m_request = r;}

public: // RequestListener
    void started(const Loader::Request*);
    void finished(const Loader::Request*);

    void data(const Loader::Request*, const char* data, int len);
    void error(const Loader::Request*);

public: // HTTPRequestListener
    void setHTTPStatus(const Loader::Request*, int);
    void setLocation(const Loader::Request*, const gchar* absoluteURL);
    void setContentType(const Loader::Request*, const gchar* contentType, const gchar* encoding);
    void setContentLength(const Loader::Request*, unsigned long contentLength);
    void setCookie(const Loader::Request*, const gchar* value);
    void setRefresh(const Loader::Request*, const gchar* value);
    void setUnknownHTTPHeader(const Loader::Request*, const gchar* key, const gchar* value);
    
private:
    void commit();
    void openURL();

    bool isNativeContent();
    bool isCommitted() const { return m_committed; }
    bool isURLOpen() const { return m_URLOpen; }
    bool contentHandlerKnown() const { return m_contentHandlerKnown; }
    void determineContentHandler();
    void determineContentType();

private:
    BridgeImpl* m_bridge;

    own_gcharptr m_url;
    own_gcharptr m_contentType;
    own_gcharptr m_encoding;
    own_gcharptr m_refresh;
    GTime m_lastModified;
    long m_contentLength;


    bool m_URLOpen;
    bool m_gotEncoding;
    bool m_gotError;
    bool m_committed;
    bool m_contentHandlerKnown;
    PageLoadStatus m_status;

    ref_gobjectptr<WebiExternalContentDelegate> m_externalDelegate;
    ref_gobjectptr<WebiResource> m_externalResource;
    Loader::Request* m_request;
    DataAdder* m_dataAdder;
};
#endif
