/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: f; c-basic-offset: 4 -*- */
/*
 * Copyright (c) 2004 Nokia. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Nokia nor the names of its contributors may be
 * used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebiRoot_h
#define WebiRoot_h

#include <glib.h>
#include <glib-object.h>

#include "webkit-gtk/webkit-view-webi-extensions.h"
#include "WebiEventListener.h"

class RootImpl;
class WebiRoot
{
    WebiEventListener listener;
    WebiLoadStatus* status;

	RootImpl* m_root;
	WebkitView* m_webkitView;

	GObject* m_signalReceiver;

    /** Current cookie after onSetCookie -call. */
    WebiCookie* cookie;

    bool internal;


public:
    WebiRoot(RootImpl*, Webi*);
	WebiRoot(RootImpl*, WebkitView* view, WebkitViewWebiSignalStub* stub);

    ~WebiRoot();
	GObject* engine() { return m_signalReceiver;}
	FrameImpl* mainFrame();
	bool isForWebkitView() const { return m_webkitView;}
    void setEmitInternal(bool flag) { internal = flag; }
    void internalStatusStart();
    void internalStatusStop(int status);
    void internalStatusStartItem(const OSB::ResourceStatus * status);
    void internalStatusHeadersItem(const OSB::ResourceStatus * status);
    void internalStatusProgressItem(const OSB::ResourceStatus * status);
    void internalStatusStopItem(const OSB::ResourceStatus * status);
    bool internalOnSetCookie(const Cookie * cookie, const gchar* url);

    const WebiLoadStatus* myStatus();
    const gchar* myLocation();
    const gchar* myTitle();

    gboolean findString(const gchar* text, gboolean case_sensitive, gboolean dir_down);
};

#endif
