/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* Copyright (c) 2007 Kimmo Kinnunen. All rights reserved.
 * bsd license
 */
#include "webi-resource.h"
#include "PageLoadListener.h"

G_DEFINE_TYPE (WebiResource, webi_resource, G_TYPE_OBJECT);

/* macro for simplifying getting the private structure */
#define WEBI_RESOURCE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), WEBI_TYPE_RESOURCE, WebiResourcePrivate))
typedef struct _WebiResourcePrivate WebiResourcePrivate;
struct _WebiResourcePrivate {
	PageLoadListener* creator;
};

static void webi_resource_finalize(WebiResource *self);

static void webi_resource_init (WebiResource *self)
{
	//FIXME: g_object_new clears the memory area?

	assert(!self->url);
	assert(!self->mime_type);
	assert(!self->user_data);

	self->content_length = -1;
}

static void webi_resource_class_init (WebiResourceClass *klass)
{
	/* register private structure */
	g_type_class_add_private(klass, sizeof(WebiResourcePrivate));

	/* bind finalizing function */
	G_OBJECT_CLASS (klass)->finalize = (GObjectFinalizeFunc) webi_resource_finalize;
}


static void webi_resource_finalize(WebiResource *self)
{
	if (self->mime_type)
		g_free (self->mime_type);

	if (self->url)
		g_free (self->url);
}

WebiResource* webi_resource_new (PageLoadListener* creator, const gchar* url, const gchar* mime_type)
{
	WebiResource* self = WEBI_RESOURCE (g_object_new (WEBI_TYPE_RESOURCE, NULL));
	self->url = g_strdup (url);
	self->mime_type = g_strdup (mime_type);

	return self;
}

void webi_resource_cancel_load (WebiResource *self)
{
	g_return_if_fail (WEBI_IS_RESOURCE (self));
	WebiResourcePrivate* priv = WEBI_RESOURCE_GET_PRIVATE (self);
	if (priv->creator) {
		priv->creator->externalLoadCancelled();
		priv->creator = 0;
	}
}

