/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * Copyright (c) 2004 Nokia. All rights reserved.
 * Copyright (c) 2007 Kimmo Kinnunen. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Nokia nor the names of its contributors may be
 * used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef loader_CurlRequest_h
#define loader_CurlRequest_h

#include <glib.h>
#include <curl/curl.h>

#include "HTTP.h"

// authentication required status code.
#define HTTP_STATUS_AUTH_REQUIRED 401

namespace Loader {
class CurlFactory;

class CurlRequest : public Request, public HTTPAuthorizee
{
    friend class CurlFactory;
public:
    CurlRequest(CurlFactory *aParent,
				RequestListener* aListener,
                HTTPHeaderListener* headerListener,
                HTTPAuthorizer* authorizer,
				const gchar* aUrl,
				const gchar* aCookies,
                bool aIsSynchronized,
				const gchar* postContentType,
                GByteArray* postData);


    ~CurlRequest();

    void execute();
    void stop();

    void error(int curlerror);

    void dataFromCurl(CURL* origin, const char* data, int len);
    void headerFromCurl(CURL* origin, const char* data, int len);

    void finish();

public: //HTTPAuthorizee
    virtual void rerequestWithCredentials(const gchar* user, const gchar* pass);

private:
    void reset();
    bool shouldRetry() { return !m_authCancelled; }

    void queueReexecute();
    bool shouldReexecute() { return m_reexecuteInProgress;}

    void cleanup();

    void setPostData(const gchar * contentType, GByteArray *);
    void freeAuthCancelHeaderList();
private:
    CurlFactory* m_parent;
    RequestListener* m_listener;
    HTTPHeaderListener* m_headerListener;
    HTTPAuthorizer* m_authorizer;

    own_gcharptr m_cookies;
    CURL *m_handle;
    curl_slist* m_curlHeaders;

    GByteArray * m_postData;
    
    int m_status;
    bool m_isSynchronous;

    bool m_headersEnd;
    bool m_finishSent;
    bool m_startSent;
    bool m_statusSent;

    own_gcharptr m_authCredentials;
    own_gcharptr m_authScheme;
    bool m_authCancelled;
    GSList* m_authCancelHeaderList;
    bool m_reexecuteInProgress;

};
}//namespace

#endif
