/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

#ifndef Loader_h
#define Loader_h

#include "Loader.h"
namespace Loader {

class HTTPHeaderListener
{
public:
    virtual ~HTTPHeaderListener() {};
    virtual void setHTTPStatus(const Request*, int status) =0;
    virtual void setLocation(const Request*, const gchar*) =0;
    virtual void setContentType(const Request*, const gchar* contentType, const gchar* encoding) =0;
    virtual void setContentLength(const Request*, unsigned long contentLength)=0;
    virtual void setCookie(const Request*, const gchar*)=0;
    virtual void setRefresh(const Request*, const gchar* value)=0;
    virtual void setUnknownHTTPHeader(const Request*, const gchar* key, const gchar* value)=0;

};

class HTTPAuthorizee
{
public:
    virtual ~HTTPAuthorizee() {};
    virtual void rerequestWithCredentials(const gchar* user, const gchar* pass) =0;
};

class HTTPAuthorizer
{
public:
    virtual ~HTTPAuthorizer() {};

    /** auth params can be set before request starts */
    virtual void HTTPAuthForURL(const gchar* URL, HTTPAuthorizee* target) =0;

    /** auth params requested during request */
    virtual void HTTPAuthRequest(const gchar* URL, const gchar* realm, HTTPAuthorizee* target) =0;
};


class HTTPFactory
{

public:
	virtual ~HTTPFactory() {};

    enum Method { POST, GET };

	virtual bool canProvide(const gchar* url) const = 0;

	virtual Request* createRequest(RequestListener* listener,
                                   HTTPHeaderListener* headerListener,
                                   HTTPAuthorizer* authorizer,
                                   const gchar* url,
                                   const gchar* cookies,
                                   bool isSynchronized,
                                   const gchar* postContentType,
                                   GByteArray* postData) =0;

	virtual void setProxy(const gchar* proto, const gchar* url) = 0;
};

HTTPFactory& getHTTPFactory();

} // namespace

#endif
