/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (c) 2004 Nokia. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the
 * distribution.
 *
 * Neither the name of Nokia nor the names of its contributors may be
 * used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef webkit_view_webi_extensions_h
#define webkit_view_webi_extensions_h

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>

#include <webkit-gtk/webkit-view.h>
/* this file is public header */

/* this file is not part of webkit-gtk api */

/* this file is part of gtk-webcore's transition api */

/**
 * This is compatibility api for webi_* usage for following two reasons:
 * - this file contains functions that support applications written against
 *   webi -interface. during transition perioid gtk-webcore can be used
 *   with new webkit-gtk api, and using these helper functions
 *
 * - some of functionality here should be written according similar to
 *   to WebView API. Since this is not done yet, this file provides
 *   "unstandard" extensions to webkit-gtk api that were present in
 *   webi
 */

G_BEGIN_DECLS

#include <webi-types.h>
#include <webkit-gtk/webkit-types.h>
#include <webkit-gtk/webkit-view-webi-types.h>

#include <webi-common-declarations.h>
#include <webi-external-content-delegate.h>


/**
 * Use this to implement save as -dialog and opening of externally handled resources
 * (like pdfs)
 */
void webkit_view_webi_set_default_external_content_delegate (WebkitView* self, WebiExternalContentDelegate*);

WebiExternalContentDelegate* webkit_view_webi_get_default_external_content_delegate (WebkitView* self);

/** deprecated!!!
 * Gets the engine user agent string.
 * The returned string can be used to construct browser-specific
 * user-agent strings
 */
const gchar* webkit_view_webi_get_engine_user_agent_string ();

GtkWidget* webkit_view_webi_new_with_signal_stub(const gchar* frame_name, const gchar* group_name);

void webkit_view_webi_set_settings(WebkitView* self, const WebiSettings* settings);

void webkit_view_webi_set_emit_internal_status (WebkitView* self, gboolean flag);


#define WEBKIT_TYPE_VIEW_WEBI_SIGNAL_STUB        (webkit_view_webi_signal_stub_get_type ())
#define WEBKIT_VIEW_WEBI_SIGNAL_STUB(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), WEBKIT_TYPE_VIEW_WEBI_SIGNAL_STUB, WebkitViewWebiSignalStub))
#define WEBKIT_VIEW_WEBI_SIGNAL_STUB_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST((klass), WEBKIT_TYPE_VIEW_WEBI_SIGNAL_STUB, WebkitViewWebiSignalStubClass))
#define WEBKIT_IS_VIEW_WEBI_SIGNAL_STUB(obj)     (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WEBKIT_TYPE_VIEW_WEBI_SIGNAL_STUB))


struct WebkitViewWebiSignalStub_ {
	WebkitView parent;
};

struct WebkitViewWebiSignalStubClass_ {
	WebkitViewClass parent_class;


  /*signals*/

  /** Location change indication signal.
   * use \webi_get_location() to get the url string
   * @emited when current page changes.
   * @param self the engine which sent the signal
   */
  void (* location) (WebkitView*  self);

  /** Title change indication signal.
   * use \webi_get_title() to get the title string
   * @emited when title of current page changes.
   * @param self the engine which sent the signal
   */
  void (* title) (WebkitView*  self);

  /** Load start indication signal.
   * @emited when page loading is started
   * @param self the engine which sent the signal
   */
  void (* load_start) (WebkitView*  self);

  /** Load start indication signal.
   * @emited when page loading is stopped.
   * @emited on error
   * @param self the engine which sent the signal
   */
  void (* load_stop) (WebkitView*  self);

  /** Set cookie indication signal.
   * @emited when a cookie is received from network
   * @param self the engine which sent the signal
   * @param url the url that tries to set the cookie.
   * @param cookie The actual cookie received.
   * @return \FALSE if don't allow cookie to be set
   *         \TRUE if cookie should be set
   */
  gboolean (* set_cookie) (WebkitView*  self, const gchar* URL, WebiCookie * cookie);

  /** javascript status change indication signal
   * use \webi_get_status_text() to get the status string
   *
   * @emited when javascript status changes.
   * @param self the engine which sent the signal
   */
  void (* status_text) (WebkitView*  self);

  /** Page load status change indication signal
   *
   * @emited when page load status changes.
   * @param self the engine which sent the signal
   * @param status status of the engine.
   */
  void (* status) (WebkitView*  self, WebiLoadStatus * status);

  /** javascript prompt and alert request signal
   * must be synchronous
   * @emited when javascript generates an alert
   * @emited when javascript generates an prompt
   *
   * @param self the engine which sent the signal
   * @param args used to pass information between browser and engine (in and out)
   *        see #WebiPromptAgs
   */
  void (* req_js_prompt) (WebkitView* self, WebiPromptArgs* args);

  /** HTTP Auth
   * must be synchronous
   * @emited when javascript generates an alert
   * @emited when javascript generates an prompt
   *
   * @param self the engine which sent the signal
   * @param args used to pass information between browser and engine (in and out)
   *        see #WebiPromptAgs
   */
  void (* req_auth_prompt) (WebkitView* self, WebiAuthArgs* args);

  /** javascript/html new window request signal
   * must be synchronous
   *
   * @emited when javascript requests to create a new window
   * @emited when html link contains target="_blank" -attribute   *
   * @param self the engine which sent the signal
   * @param url the URL string loading by newengine.
   * @return newengine The new engine of the new window
   *        or \NULL if new window creation is not allowed
   */
  WebkitView*  (* req_new_window) (WebkitView* self, const gchar *url);

  void (* show_window) (WebkitView* self);
  void (* close_window) (WebkitView* self);

  void (* set_window_properties) (WebkitView* self, WebiWindowProperties* features);
  void (* get_window_size) (WebkitView* self, WebiWindowSize * type, GtkAllocation * size);
  void (* set_window_size) (WebkitView* self, WebiWindowSize * type, GtkRequisition * size);


  /** Set device type signal
   * must be synchronous
   *
   * @emited when user wants to change device type used in rendering and
   *         style sheet selection
   * @param self the engine which sent the signal
   * @param newDeviceType The new device type of current window
   */
  void (* set_device_type) (WebkitView* self, WebiDeviceType type);

  /** Get device type signal
   * must be synchronous
   *
   * @emited when user wants to change device type used in rendering and
   *         style sheet selection
   * @param self the engine which sent the signal
   * @param newDeviceType The new device type of current window
   */
  WebiDeviceType (* get_device_type) (WebkitView* self);

  void (* mouse_over) (WebkitView* self, const gchar* link_title, const gchar* link_label, const gchar* link_url, const gchar* link_target);

  /** selection change signal*/
  void (* selection) (WebkitView* self);
};

GType webkit_view_webi_signal_stub_get_type();

/* get signal stub which you can use to connect old type webi signals
 */
WebkitViewWebiSignalStub* webkit_view_webi_get_signal_stub(WebkitView* self);

G_END_DECLS

#endif
